"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
/* eslint-disable no-console */
const chalk_1 = (0, tslib_1.__importDefault)(require("chalk"));
const fs_extra_1 = require("fs-extra");
const path_1 = require("path");
const paths_1 = require("../config/paths");
const updateLicense_1 = (0, tslib_1.__importDefault)(require("./fns/updateLicense"));
const updateREADMEFile_1 = (0, tslib_1.__importDefault)(require("./fns/updateREADMEFile"));
const genDoczFiles_1 = (0, tslib_1.__importDefault)(require("./genDoczFiles"));
/**
 * 更新模块配置信息
 *
 * @param projectPath 项目路径
 * @param options 配置
 */
async function updatePackageInfo(projectPath, options) {
    const packagePath = (0, path_1.resolve)(projectPath, 'package.json');
    const packageInfo = await (0, fs_extra_1.readJSON)(packagePath);
    packageInfo.version = options.packageVersion;
    packageInfo.name = options.packageName;
    packageInfo.description = options.packageDescription;
    packageInfo.workspaces = ['packages/*'];
    packageInfo.scripts.gen = 'ts-lib-tools gen-module';
    packageInfo.scripts.release = 'lerna publish --contents dist';
    packageInfo.private = true;
    delete packageInfo.publishConfig;
    delete packageInfo.sideEffects;
    delete packageInfo.main;
    delete packageInfo['umd:main'];
    delete packageInfo['module'];
    delete packageInfo.types;
    await (0, fs_extra_1.outputJSON)(packagePath, packageInfo, {
        spaces: 2,
    });
}
/**
 * 更新项目配置
 *
 * @param projectPath 项目路径
 * @param options 配置
 */
async function updateProjectConfig(projectPath, options) {
    const configPath = (0, path_1.resolve)(projectPath, 'ts-lib.config.json');
    const projectConfig = await (0, fs_extra_1.readJSON)(configPath);
    projectConfig.npmScope = options.npmScope || options.packageName;
    await (0, fs_extra_1.outputJSON)(configPath, projectConfig, {
        spaces: 2,
    });
}
/**
 * 更新tsconfig配置
 *
 * @param projectPath 项目路径
 * @param options 配置
 */
async function updateTsConfig(projectPath, options) {
    const tsconfigPath = (0, path_1.resolve)(projectPath, 'tsconfig.json');
    const tsconfig = await (0, fs_extra_1.readJSON)(tsconfigPath);
    tsconfig.compilerOptions.paths = {
        [`@${options.npmScope || options.packageName}/*`]: ['packages/*/src'],
    };
    await (0, fs_extra_1.outputJSON)(tsconfigPath, tsconfig, {
        spaces: 2,
    });
}
/**
 * 生成monorepo模式的项目
 *
 * @param options 配置
 */
async function genMonorepoProject(options) {
    const projectPath = (0, paths_1.resolveRoot)(options.projectName);
    const exists = await (0, fs_extra_1.pathExists)(projectPath);
    if (exists) {
        console.error(chalk_1.default.red(`已经存在${options.projectName}文件夹，请选择一个新的项目名称。`));
        process.exit(1);
    }
    await (0, fs_extra_1.copy)(paths_1.COMMON_TEMPLATE_PATH, projectPath);
    await (0, fs_extra_1.copy)(paths_1.MONOREPO_TEMPLATE_PATH, projectPath);
    await (0, fs_extra_1.copy)(paths_1.GIT_IGNORE_FILE_PATH, (0, path_1.resolve)(projectPath, '.gitignore'));
    await updatePackageInfo(projectPath, options);
    await updateProjectConfig(projectPath, options);
    await (0, updateREADMEFile_1.default)(projectPath, options);
    await (0, updateLicense_1.default)(projectPath, options);
    await updateTsConfig(projectPath, options);
    await (0, fs_extra_1.remove)((0, path_1.resolve)(projectPath, 'src'));
    if (options.docz) {
        await (0, genDoczFiles_1.default)(projectPath, options);
        await (0, fs_extra_1.remove)((0, path_1.resolve)(projectPath, 'docs/Counter.mdx'));
    }
}
exports.default = genMonorepoProject;
//# sourceMappingURL=genMonorepoProject.js.map